pub fn healthy_builders(statuses: &[HealthStatus]) -> Vec<&HealthStatus>Expand description
Get only healthy builders, sorted by speed factor (highest first).
pub fn healthy_builders(statuses: &[HealthStatus]) -> Vec<&HealthStatus>Get only healthy builders, sorted by speed factor (highest first).